# Screenshot Skill

Take screenshots by voice

![screen-124907-181124](https://github.com/user-attachments/assets/dde3b4ec-33f2-4f2c-a17f-2b8550c4cc81)

> **Supported platforms**: ovos-shell, Windows, macOS, Linux, and OpenBSD

## Examples
* "take a screenshot" 
* "capture the screen",
